@@ -2,7 +2,6 @@ from . import SentenceEvaluator
 import torch
 from torch.utils.data import DataLoader
 import logging
-from tqdm import tqdm
 from ..util import batch_to_device
 import os
 import csv
@@ -19,7 +18,7 @@ class LabelAccuracyEvaluator(SentenceEvaluator):
     The results are written in a CSV. If a CSV already exists, then values are appended.
     """
 
-    def __init__(self, dataloader: DataLoader, name: str = "", softmax_model = None):
+    def __init__(self, dataloader: DataLoader, name: str = "", softmax_model = None, write_csv: bool = True):
         """
         Constructs an evaluator for the given dataset
 
@@ -33,6 +32,7 @@ class LabelAccuracyEvaluator(SentenceEvaluator):
         if name:
             name = "_"+name
 
+        self.write_csv = write_csv
         self.csv_file = "accuracy_evaluation"+name+"_results.csv"
         self.csv_headers = ["epoch", "steps", "accuracy"]
 
@@ -51,8 +51,11 @@ class LabelAccuracyEvaluator(SentenceEvaluator):
 
         logger.info("Evaluation on the "+self.name+" dataset"+out_txt)
         self.dataloader.collate_fn = model.smart_batching_collate
-        for step, batch in enumerate(tqdm(self.dataloader, desc="Evaluating")):
-            features, label_ids = batch_to_device(batch, model.device)
+        for step, batch in enumerate(self.dataloader):
+            features, label_ids = batch
+            for idx in range(len(features)):
+                features[idx] = batch_to_device(features[idx], model.device)
+            label_ids = label_ids.to(model.device)
             with torch.no_grad():
                 _, prediction = self.softmax_model(features, labels=None)
 
@@ -62,7 +65,7 @@ class LabelAccuracyEvaluator(SentenceEvaluator):
 
         logger.info("Accuracy: {:.4f} ({}/{})\n".format(accuracy, correct, total))
 
-        if output_path is not None:
+        if output_path is not None and self.write_csv:
             csv_path = os.path.join(output_path, self.csv_file)
             if not os.path.isfile(csv_path):
                 with open(csv_path, mode="w", encoding="utf-8") as f:
